from .colorlog import Logger, OK

__title__ = "exencolorlogs"
__version__ = 0.4
__author__ = "Exenifix"
